summaryrefslogtreecommitdiff
path: root/compiler/GHC/Core/Opt/Arity.hs
diff options
context:
space:
mode:
Diffstat (limited to 'compiler/GHC/Core/Opt/Arity.hs')
-rw-r--r--compiler/GHC/Core/Opt/Arity.hs8
1 files changed, 3 insertions, 5 deletions
diff --git a/compiler/GHC/Core/Opt/Arity.hs b/compiler/GHC/Core/Opt/Arity.hs
index 36a2535c09..aa0b936058 100644
--- a/compiler/GHC/Core/Opt/Arity.hs
+++ b/compiler/GHC/Core/Opt/Arity.hs
@@ -1672,11 +1672,9 @@ pushCoValArg co
-- then co1 :: tyL1 ~ tyR1
-- co2 :: tyL2 ~ tyR2
= ASSERT2( isFunTy tyR, ppr co $$ ppr arg )
- Just (coToMCo (mkSymCo co1), coToMCo co2)
- -- Critically, coToMCo to checks for ReflCo; the whole coercion may not
- -- be reflexive, but either of its components might be
- -- We could use isReflexiveCo, but it's not clear if the benefit
- -- is worth the cost, and it makes no difference in #18223
+ Just (mkMCo (mkSymCo co1), mkMCo co2)
+ -- Critically, mkMCo to checks for isReflexiveCo; the whole coercion
+ -- may not be reflexive, but either of its components might be
| otherwise
= Nothing